#!/usr/bin/perl
#
# proc_gps.pl
#
# Description: strip out GPS data (string 011) from athena log files
# For GPS - parse out Time Lat Lon
#
# C. Sellers 1/15/01
# sftre cruise OC365
#
# Usage: proc_gps.pl [logfile]
#	Default output to stdout unless logfile specified
#
####################################################################

require "flush.pl";

#if ($#ARGV < 0) {
#    print "Usage: $0 [logfile]\n";
#    exit;
#}

#setup args
if ($#ARGV == 0)
   {$logfile = $ARGV[0];}

if ($logfile ne "")  {
    if (! open(LOG,">>$logfile") ) {
	print "$0: ***Error - unable to open logfile [$logfile]\n";
    }
}
$strpattern = "011";

#read from stdin
while ($line=<STDIN>) {
    chomp($line);
    next if ($line eq ""); #skip blank lines
    ($date,$time,$dum1,$dum2,$at,$lat,$lon,$reat) = split(/,/,$line);
    ($year,$month,$day)=split('/',$date);
    ($hour,$minit,$sec)=split(':',$time);
    # output results
    if ($logfile eq  "") {
	if ($time & $lat & $lon) {
	    print "$year $month $day $hour $minit $sec $lat $lon\n";
	}
    }
    else {
	print LOG "$time $lat $lon\n";
	flush(LOG);
    }
}

exit;



############################################################
# Generic Misc Sub Routines
#
sub check_argv {
	local($i);
	print "NUM ARGS $#ARGV\n";
	for ($i=0;$i<=$#ARGV;$i++) {
		print "ARG[$i] = $ARGV[$i] \n";
	}
}

sub printenv {
	local($key);
	for $key (sort keys %ENV) {
	    print "$key=$ENV{$key}\n";
	}
}

sub gethostname {
	local($cmd) = "/usr/ucb/hostname";
	local($hostname);
     	open(CMD,"$cmd |") || return "***Can't open $cmd";
     	$hostname = <CMD>;
	close(CMD);
	return $hostname;
}


sub sec2hhmmss {#takes total seconds and returns d hh:mm:ss
	local($sec) = $_[0];
	local($dy,$hr,$mn,$sc);
	$dy = int($sec/86400);
	$hr = int(($sec - ($dy*86400))/3600);
	$mn = int(($sec - ($dy*86400) - ($hr*3600))/60);
	$sc = $sec - ($dy*86400) - ($hr*3600) - ($mn*60);
	if ($hr < 10) {$hr = "0$hr";}
	if ($mn < 10) {$mn = "0$mn";}
	if ($sc < 10) {$sc = "0$sc";}

	if ($dy == 0) {return "$hr:$mn:$sc";}
	         else {return "$dy $hr:$mn:$sc";}
}


sub gmtimestamp {
        local($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = gmtime;
   	# zero fill hour,min,sec and month
   	if ($sec < 10) {$sec = "0$sec";}
   	if ($min < 10) {$min = "0$min";}
   	if ($hour < 10) {$hour = "0$hour";}
   	$mon += 1; #from gmtime defined 0-11, make it 1-12
   	if ($mon < 10) {$mon = "0$mon";}
   	if ($mday < 10) {$mday = "0$mday";}
   	#make year 4-digits - note will fail in 2099!
   	if (length($year) == 2)
   	   {if ($year == 99) {$year += 1900;}
   	                else {$year += 2000;}
   	    }
   	return "$year/$mon/$mday $hour:$min:$sec GMT"; 
}

sub gmtimestamp_file {
   	local($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = gmtime;
   	# zero fill hour,min,sec and month
   	if ($sec < 10) {$sec = "0$sec";}
   	if ($min < 10) {$min = "0$min";}
   	if ($hour < 10) {$hour = "0$hour";}
   	$mon += 1; #from gmtime defined 0-11, make it 1-12
   	if ($mon < 10) {$mon = "0$mon";}
   	if ($mday < 10) {$mday = "0$mday";}
   	#make year 4-digits - note: will fail in 2099!
   	if (length($year) == 2)
   	   {if ($year == 99) {$year += 1900;}
   	                else {$year += 2000;}
   	    }
   	return "$year$mon$mday\_$hour$min"; 
}

sub gmtimestamp_file_ss {
   	local($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = gmtime;
   	# zero fill hour,min,sec and month
   	if ($sec < 10) {$sec = "0$sec";}
   	if ($min < 10) {$min = "0$min";}
   	if ($hour < 10) {$hour = "0$hour";}
   	$mon += 1; #from gmtime defined 0-11, make it 1-12
   	if ($mon < 10) {$mon = "0$mon";}
   	if ($mday < 10) {$mday = "0$mday";}
   	#make year 4-digits - note: will fail in 2099!
   	if (length($year) == 2)
   	   {if ($year == 99) {$year += 1900;}
   	                else {$year += 2000;}
   	    }
   	return "$year$mon$mday\_$hour$min$sec"; 
}

sub gmtimestamp_yyyymmdd {
   	local($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = gmtime;
   	# zero fill month
   	$mon += 1; #from gmtime defined 0-11, make it 1-12
   	if ($mon < 10) {$mon = "0$mon";}
   	if ($mday < 10) {$mday = "0$mday";}
   	#make year 4-digits - note: will fail in 2099!
   	if (length($year) == 2)
   	   {if ($year == 99) {$year += 1900;}
   	                else {$year += 2000;}
   	    }
   	return "$year$mon$mday"; 
}

sub time2yyyymmdd {
        my($time) = $_[0]; #optional - if not set, uses current time
        my($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst);
        if ($time eq "")
   	  {($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = gmtime;}
   	else
   	  {($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = gmtime($time);}
   	# zero fill hour,min,sec and month
   	if ($sec < 10) {$sec = "0$sec";}
   	if ($min < 10) {$min = "0$min";}
   	if ($hour < 10) {$hour = "0$hour";}
   	$mon += 1; #from gmtime defined 0-11, make it 1-12
   	if ($mon < 10) {$mon = "0$mon";}
   	if ($mday < 10) {$mday = "0$mday";}
   	#make year 4-digits - note will fail in 2099!
   	if (length($year) == 2)
   	   {if ($year == 99) {$year += 1900;}
   	                else {$year += 2000;}
   	    }
   	return "$year/$mon/$mday $hour:$min:$sec GMT"; 
}



#------------------------------------------------------------

